# Changelog

## [1.4.1]  - 2025-01-11

### Fixed: 

- downloading way too much data to cover overseas territories

## [1.4.0]  - 2025-01-08

### Added:

- API 
- Programming examples for API use

### Changed:

- Updated documentation


## [1.2.0] - 2025-01-05

### Added:

- CLI with argparse
- Country boundary support
- Logging system
- Convenience script test_country_intersection.py
- CI/CD integration

## [1.1.0] - 2025-12-29

### Added:

- add_bbox_to_tiles.py script to annotate preexisting tiles

### Changed:

- Streaming JSON parsing
- Replaced shapely with GDAL/OGR
- Memory optimizations
- Coordinate conversion

## [1.0.0] - 2025-12-29

- Initial release
- Basic functionality
